Forced Network Rule
-------------------

.. automodule:: qarnot.forced_network_rule
    :members:
    :show-inheritance:
    :special-members:
    :exclude-members: __dict__,__weakref__,__eq__,__str__,__repr__